@@ -1,11 +1,11 @@
-deconstruct <- function(P, P.context) {
+deconstruct <- function(P, P.context, topo) {
 
   # Fraction in a context
   if (P$fraction) {
     if (length(P$sumset) == 0) {
       if (P.context$fraction) {
-        P.context$num <- deconstruct(P$num, P.context$num)
-        P.context$den <- deconstruct(P$den, P.context$den)
+        P.context$num <- deconstruct(P$num, P.context$num, topo)
+        P.context$den <- deconstruct(P$den, P.context$den, topo)
         return(P.context)
       }
       if (P.context$product) {
@@ -13,28 +13,28 @@ deconstruct <- function(P, P.context) {
         P.temp$fraction <- TRUE
         P.temp$sumset <- P.context$sumset
         P.context$sumset <- character(0)
-        P.temp$num <- deconstruct(P$num, P.context)
-        P.temp$den <- deconstruct(P$den, probability())
+        P.temp$num <- deconstruct(P$num, P.context, topo)
+        P.temp$den <- deconstruct(P$den, probability(), topo)
         return(P.temp)
       }
       if (P.context$sum) {
-        P.context$children[[length(P.context$children)+1]] <- deconstruct(P, probability())
+        P.context$children[[length(P.context$children)+1]] <- deconstruct(P, probability(), topo)
         return(P.context)
       }
     } else {
       if (P.context$fraction) {
-        P.context$num <- deconstruct(P, P.context$num)
+        P.context$num <- deconstruct(P, P.context$num, topo)
         return(P.context)
       }
       if (P.context$product || P.context$sum) {
-        P.context$children[[length(P.context$children)+1]] <- deconstruct(P, probability())
+        P.context$children[[length(P.context$children)+1]] <- deconstruct(P, probability(), topo)
         return(P.context)
       }
     }
     P.context$fraction <- TRUE
     P.context$sumset <- P$sumset
-    P.context$num <- deconstruct(P$num, probability())
-    P.context$den <- deconstruct(P$den, probability())
+    P.context$num <- deconstruct(P$num, probability(), topo)
+    P.context$den <- deconstruct(P$den, probability(), topo)
     return(P.context)
   }
 
@@ -42,17 +42,17 @@ deconstruct <- function(P, P.context) {
   if (P$product) {
     if (length(P$sumset) == 0) {
       if (P.context$fraction) {
-        P.context$num <- deconstruct(P, P.context$num)
+        P.context$num <- deconstruct(P, P.context$num, topo)
         return(P.context)
       }
       if (P.context$product) {
         for (i in 1:length(P$children)) {
-          P.context <- deconstruct(P$children[[i]], P.context)
+          P.context <- deconstruct(P$children[[i]], P.context, topo)
         }
         return(P.context)
       }
       if (P.context$sum) {
-        P.context$children[[length(P.context$children)+1]] <- deconstruct(P, probability())
+        P.context$children[[length(P.context$children)+1]] <- deconstruct(P, probability(), topo)
       }
     } else {
       if (P.context$fraction) {
@@ -60,14 +60,14 @@ deconstruct <- function(P, P.context) {
         return(P.context)
       }
       if (P.context$product || P.context$sum) {
-        P.context$children[[length(P.context$children)+1]] <- deconstruct(P, probability())
+        P.context$children[[length(P.context$children)+1]] <- deconstruct(P, probability(), topo)
         return(P.context)
       }
     }
     P.context$product <- TRUE
     P.context$sumset <- P$sumset
     for (i in 1:length(P$children)) {
-      P.context <- deconstruct(P$children[[i]], P.context)
+      P.context <- deconstruct(P$children[[i]], P.context, topo)
     }
     return(P.context)
   }
@@ -75,47 +75,41 @@ deconstruct <- function(P, P.context) {
   # Sum in a context
   if (P$sum) {
     if (P.context$fraction) {
-      P.context$num <- deconstruct(P, P.context$num)
+      P.context$num <- deconstruct(P, P.context$num, topo)
       return(P.context)
     }
     if (P.context$product || P.context$sum) {
-      P.context$children[[length(P.context$children)+1]] <- deconstruct(P, probability())
+      P.context$children[[length(P.context$children)+1]] <- deconstruct(P, probability(), topo)
       return(P.context)
     }
     P.context$sum <- TRUE
     P.context$sumset <- P$sumset
     for (i in 1:length(P$children)) {
-      P.context <- deconstruct(P$children[[i]], P.context)
+      P.context <- deconstruct(P$children[[i]], P.context, topo)
     }
     return(P.context)
   }
 
   # Atomic expression in a context
   if (P.context$fraction) {
-    P.context$num <- deconstruct(P, P.context$num)
+    P.context$num <- deconstruct(P, P.context$num, topo)
     return(P.context)
   }
 
   if (P.context$product) {
-    init <- length(P.context$children) 
+    init <- length(P.context$children)
     if (length(P$sumset) == 0) {
-      P.temp <- probability(var = P$var[1], cond = union(P$cond, P$var[-1]),
-        domain = P$domain, do = P$do)
-      P.context$children[[init + 1]] <- P.temp
-      if (length(P$var) > 1) {
-        for (i in 2:length(P$var)) {
-          P.temp <- probability(var = P$var[i], cond = union(P$cond, P$var[-(1:i)]),
-            domain = P$domain, do = P$do)
-          P.context$children[[init + i]] <- P.temp
-        }
+      n <- length(P$var)
+      for (i in n:1) {
+        P.context$children[[init + i]] <- probability(var = P$var[i], cond = union(P$cond, P$var[-(i:n)]) %ts% topo,
+          domain = P$domain, do = P$do)
       }
     } else {
-      if (length(P$var) > 1) {
-        P.temp <- probability(product = TRUE, children = list(), sumset = P$sumset) 
-        P.temp$children[[1]] <- probability(var = P$var[1], cond = union(P$cond, P$var[-1]),
-          domain = P$domain, do = P$do)
-        for (i in 2:length(P$var)) {
-          P.temp$children[[i]] <- probability(var = P$var[i], cond = union(P$cond, P$var[-(1:i)]),
+      n <- length(P$var)
+      if (n > 1) {
+        P.temp <- probability(product = TRUE, children = list(), sumset = P$sumset)
+        for (i in n:1) {
+          P.temp$children[[n-1+1]] <- probability(var = P$var[i], cond = union(P$cond, P$var[-(i:n)]) %ts% topo,
             domain = P$domain, do = P$do)
         }
         P.context$children[[init + 1]] <- P.temp
@@ -125,18 +119,29 @@ deconstruct <- function(P, P.context) {
   }
 
   if (P.context$sum) {
+    init <- length(P.context$children)
     P.temp <- probability(product = TRUE, children = list(), sumset = P$sumset) 
-    P.temp$children[[1]] <- probability(var = P$var[1], cond = union(P$cond, P$var[-1]),
-      domain = P$domain, do = P$do)
-    if (length(P$var) > 1) {
-      for (i in 2:length(P$var)) {
-        P.temp$children[[i]] <- probability(var = P$var[i], cond = union(P$cond, P$var[-(1:i)]),
-          domain = P$domain, do = P$do)
-      }
+    n <- length(P$var)
+    for (i in n:1) {
+      P.temp$children[[n-i+1]] <- probability(var = P$var[i], cond = union(P$cond, P$var[-(i:n)]) %ts% topo,
+        domain = P$domain, do = P$do)
     }
     P.context$children[[init + 1]] <- P.temp
     return(P.context)
   }
 
+  # Atomic expression with multiple variables
+  n <- length(P$var)
+  if (n > 1) {
+    P.context$product <- TRUE
+    P.context$sumset <- P$sumset
+    P.context$children <- list()
+    for (i in n:1) {
+      P.context$children[[n-i+1]] <- probability(var = P$var[i], cond = union(P$cond, P$var[-(i:n)]) %ts% topo,
+        domain = P$domain, do = P$do)
+    }
+    return(P.context)
+  }
+
   return(P)
 }
\ No newline at end of file
