@@ -1,5 +1,7 @@
 id <- function(y, x, P, G, G.obs, v, topo, tree) {
   to <- NULL
+  from <- NULL
+  description <- NULL
   if (length(P$var) == 0 & !(P$product | P$fraction)) tree$call <- list(y = y, x = x, P = probability(var = v), G = G, line = "", v = v)
   else tree$call <- list(y = y, x = x, P = P, G = G, line = "", v = v)
 
@@ -36,20 +38,12 @@ id <- function(y, x, P, G, G.obs, v, topo, tree) {
   }
 
   # line 3
-  G.xbar <- subgraph.edges(G, E(G)[!to(x)], delete.vertices = FALSE)
+  G.xbar <- subgraph.edges(G, E(G)[!(to(x) | (from(x) & (description == "U" & !is.na(description))))], delete.vertices = FALSE)
   an.xbar <- ancestors(y, observed.graph(G.xbar), topo)
   w <- setdiff(setdiff(v, x), an.xbar)
   w.len <- length(w)
   if (w.len != 0) {
-    co <- connected(w, y, G.xbar, topo)
-    if (length(co) < w.len) {
-      v.new <- setdiff(v, setdiff(w, co))
-      G <- induced.subgraph(G, v.new)
-      G.obs <- observed.graph(G)
-      v <- v.new
-    }
-    nxt <- id(y, union(x, co) %ts% topo, P, G, G.obs, v, topo, list())
-    # nxt <- id(y, union(x, w), P, G, topo, list())
+    nxt <- id(y, union(x, w) %ts% topo, P, G, G.obs, v, topo, list())
     tree$branch[[1]] <- nxt$tree
     tree$call$line <- 3
     tree$call$w <- w
