@@ -1,4 +1,7 @@
 aux.effect <- function(y, x, z, G, expr = TRUE, simp = TRUE, steps = FALSE, primes = FALSE) {
+  if (length(edge.attributes(G)) == 0) {
+    G <- set.edge.attribute(G, "description", 1:length(E(G)), NA)
+  }
   res <- generalize(y = y, x = x, Z = list(z), D = list(G), expr = FALSE, simp = simp, steps = steps, primes = primes)
   if (class(res) == "probability") {
     attr(res, "algorithm") <- "zid"
